@@ -17,6 +17,10 @@ class VncConnectionDetails:
     def port(self):
         return self._parsed_url.port
 
+    @property
+    def scheme(self):
+        return self._parsed_url.scheme
+
     @property
     def path(self):
         return f"{self._parsed_url.path}?{self._parsed_url.query}"
